"""Smoke tests for src/pact/agents/research.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_agents_research():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.agents.research")
    assert mod is not None

def test_research_phase_is_callable():
    """Function research_phase exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.agents.research")
    fn = getattr(mod, "research_phase", None)
    assert fn is not None, "'research_phase' not found in pact.agents.research"
    assert callable(fn)

def test_plan_and_evaluate_is_callable():
    """Function plan_and_evaluate exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.agents.research")
    fn = getattr(mod, "plan_and_evaluate", None)
    assert fn is not None, "'plan_and_evaluate' not found in pact.agents.research"
    assert callable(fn)

def test_research_for_group_is_callable():
    """Function research_for_group exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.agents.research")
    fn = getattr(mod, "research_for_group", None)
    assert fn is not None, "'research_for_group' not found in pact.agents.research"
    assert callable(fn)

def test_augment_research_is_callable():
    """Function augment_research exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.agents.research")
    fn = getattr(mod, "augment_research", None)
    assert fn is not None, "'augment_research' not found in pact.agents.research"
    assert callable(fn)
