"""Smoke tests for src/pact/backends/gemini.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_backends_gemini():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.backends.gemini")
    assert mod is not None
