"""Smoke tests for src/pact/daemon.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_daemon():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.daemon")
    assert mod is not None

def test_parse_directive_is_callable():
    """Function parse_directive exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.daemon")
    fn = getattr(mod, "parse_directive", None)
    assert fn is not None, "'parse_directive' not found in pact.daemon"
    assert callable(fn)

def test_send_signal_is_callable():
    """Function send_signal exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.daemon")
    fn = getattr(mod, "send_signal", None)
    assert fn is not None, "'send_signal' not found in pact.daemon"
    assert callable(fn)

def test_check_daemon_health_is_callable():
    """Function check_daemon_health exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.daemon")
    fn = getattr(mod, "check_daemon_health", None)
    assert fn is not None, "'check_daemon_health' not found in pact.daemon"
    assert callable(fn)
