"""Smoke tests for src/pact/decomposer.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_decomposer():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.decomposer")
    assert mod is not None

def test_run_register_establishment_is_callable():
    """Function run_register_establishment exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.decomposer")
    fn = getattr(mod, "run_register_establishment", None)
    assert fn is not None, "'run_register_establishment' not found in pact.decomposer"
    assert callable(fn)

def test_run_interview_is_callable():
    """Function run_interview exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.decomposer")
    fn = getattr(mod, "run_interview", None)
    assert fn is not None, "'run_interview' not found in pact.decomposer"
    assert callable(fn)

def test_run_decomposition_is_callable():
    """Function run_decomposition exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.decomposer")
    fn = getattr(mod, "run_decomposition", None)
    assert fn is not None, "'run_decomposition' not found in pact.decomposer"
    assert callable(fn)

def test_decompose_and_contract_is_callable():
    """Function decompose_and_contract exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.decomposer")
    fn = getattr(mod, "decompose_and_contract", None)
    assert fn is not None, "'decompose_and_contract' not found in pact.decomposer"
    assert callable(fn)
