"""Smoke tests for src/pact/schemas_testgen.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_schemas_testgen():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.schemas_testgen")
    assert mod is not None
