"""Smoke tests for src/pact/integrator.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_integrator():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.integrator")
    assert mod is not None

def test_integrate_component_is_callable():
    """Function integrate_component exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.integrator")
    fn = getattr(mod, "integrate_component", None)
    assert fn is not None, "'integrate_component' not found in pact.integrator"
    assert callable(fn)

def test_integrate_all_is_callable():
    """Function integrate_all exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.integrator")
    fn = getattr(mod, "integrate_all", None)
    assert fn is not None, "'integrate_all' not found in pact.integrator"
    assert callable(fn)

def test_integrate_component_iterative_is_callable():
    """Function integrate_component_iterative exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.integrator")
    fn = getattr(mod, "integrate_component_iterative", None)
    assert fn is not None, "'integrate_component_iterative' not found in pact.integrator"
    assert callable(fn)

def test_integrate_all_iterative_is_callable():
    """Function integrate_all_iterative exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.integrator")
    fn = getattr(mod, "integrate_all_iterative", None)
    assert fn is not None, "'integrate_all_iterative' not found in pact.integrator"
    assert callable(fn)
