"""Smoke tests for src/pact/standards.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_standards():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.standards")
    assert mod is not None

def test_collect_standards_is_callable():
    """Function collect_standards exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.standards")
    fn = getattr(mod, "collect_standards", None)
    assert fn is not None, "'collect_standards' not found in pact.standards"
    assert callable(fn)

def test_render_standards_brief_is_callable():
    """Function render_standards_brief exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.standards")
    fn = getattr(mod, "render_standards_brief", None)
    assert fn is not None, "'render_standards_brief' not found in pact.standards"
    assert callable(fn)
