"""Smoke tests for src/pact/design_doc.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_design_doc():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.design_doc")
    assert mod is not None

def test_render_design_doc_is_callable():
    """Function render_design_doc exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.design_doc")
    fn = getattr(mod, "render_design_doc", None)
    assert fn is not None, "'render_design_doc' not found in pact.design_doc"
    assert callable(fn)

def test_update_design_doc_is_callable():
    """Function update_design_doc exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.design_doc")
    fn = getattr(mod, "update_design_doc", None)
    assert fn is not None, "'update_design_doc' not found in pact.design_doc"
    assert callable(fn)
