"""Smoke tests for src/pact/analyzer.py (auto-generated by pact adopt)."""

import pytest

def test_import_pact_analyzer():
    """Module imports without error."""
    import importlib
    mod = importlib.import_module("pact.analyzer")
    assert mod is not None

def test_analyze_project_is_callable():
    """Function analyze_project exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.analyzer")
    fn = getattr(mod, "analyze_project", None)
    assert fn is not None, "'analyze_project' not found in pact.analyzer"
    assert callable(fn)

def test_render_analysis_markdown_is_callable():
    """Function render_analysis_markdown exists and is callable."""
    import importlib
    mod = importlib.import_module("pact.analyzer")
    fn = getattr(mod, "render_analysis_markdown", None)
    assert fn is not None, "'render_analysis_markdown' not found in pact.analyzer"
    assert callable(fn)
